# Task Models

Classes for representing tasks and task categories.

## Task

::: grocy.data_models.task.Task
    options:
      members_order: source

## TaskCategory

::: grocy.data_models.task.TaskCategory
    options:
      members_order: source
